<?php
/**
 * Plugin Name:       Google reCaptcha for WooCommerce
 * Plugin URI:        https://woocommerce.com/products/koala-google-recaptcha-for-woocommerce
 * Description:       Add reCaptcha to your WooCommerce and WordPress login, registration, reset password and other pages.
 * Version:           1.3.1
 * Author:            KoalaApps
 * Developed By:      KoalaApps
 * Author URI:        https://woocommerce.com/vendor/koalaapps/
 * Support:           https://woocommerce.com/vendor/koalaapps/
 * License:           GNU General Public License v3.0
 * License URI:       http://www.gnu.org/licenses/gpl-3.0.html
 * Domain Path:       /languages
 * Text Domain:       recaptcha_verification
 * WC requires at least: 3.0.9
 * WC tested up to: 8.*.*
 * Woo: 7673745:724159e27ebb90c2e770cafffa65ec6a
 *
 * @package Google_reCaptcha_for_WooCommerce
 */

if ( ! defined( 'ABSPATH' ) ) {
	die;
}

if ( ! class_exists( 'Main_Ka_Add_Recaptcha' ) ) {
	/**
	 * This class initializes and manages the core functionality of the plugin.
	 */
	class Main_Ka_Add_Recaptcha {
		/**
		 * Function construct start.
		 */
		public function __construct() {
			$this->ka_grc_global_constents_vars();
			add_action( 'init', array( $this, 'ka_grc_admin_init' ) );
			// HOPS compatibility.
			add_action( 'before_woocommerce_init', array( $this, 'ka_grc_hops_compatibility' ) );
		}

		/**
		 * Hooks into necessary actions to set up plugin.
		 */
		public function ka_grc_admin_init() {
			$options_to_update = array(
				'captcha_type_option'                   => array( 'v2', 'v3' ),
				'check_out_page_captcha_themes'         => array( 'light', 'dark' ),
				'guest_checkout_add_captcha_size_radio' => array( 'normal', 'compact' ),
				'login_add_captcha_authentication_key_fields' => array( 'light', 'dark' ),
				'login_add_captcha_size_radio'          => array( 'normal', 'compact' ),
				'woo_lpass_add_captcha_authentication_key_fields' => array( 'light', 'dark' ),
				'woo_lpass_add_captcha_size_radio'      => array( 'normal', 'compact' ),
				'p_order_authentication_key_radio'      => array( 'light', 'dark' ),
				'p_order_add_captcha_size_radio'        => array( 'normal', 'compact' ),
				'p_method_captcha_themes'               => array( 'light', 'dark' ),
				'p_method_add_captcha_size_radio'       => array( 'normal', 'compact' ),
				'product_review_page_captcha_themes'    => array( 'light', 'dark' ),
				'product_review_add_captcha_size_radio' => array( 'normal', 'compact' ),
				'woo_regs_add_captcha_authentication_key_fields' => array( 'light', 'dark' ),
				'add_captcha_size_radio'                => array( 'normal', 'compact' ),
				'wp_comment_captcha_theme_fields'       => array( 'light', 'dark' ),
				'wp_comment_add_captcha_size_radio'     => array( 'normal', 'compact' ),
				'wp_login_captcha_theme_fields'         => array( 'light', 'dark' ),
				'wp_login_captcha_size_radio'           => array( 'normal', 'compact' ),
				'wp_lpass_add_captcha_authentication_key_fields' => array( 'light', 'dark' ),
				'wp_lpass_add_captcha_size_radio'       => array( 'normal', 'compact' ),
				'wp_regs_captcha_theme_fields'          => array( 'light', 'dark' ),
				'wp_regs_add_captcha_size_radio'        => array( 'normal', 'compact' ),
			);

			foreach ( $options_to_update as $option => $values ) {
				if ( get_option( $option ) === (string) 1 ) {
					update_option( $option, $values[0] );
				} elseif ( get_option( $option ) === (string) 0 ) {
					update_option( $option, $values[1] );
				}
			}

			add_action( 'after_setup_theme', array( $this, 'ka_grc_textdomain' ) );
			add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), array( $this, 'ka_grc_plugin_action_links' ) );

			include_once KA_PLUGIN_DIR . 'includes/class-ajax-controller-ka-add-recaptcha.php';
			if ( is_admin() ) {
				include_once KA_PLUGIN_DIR . '/includes/admin/class-admin-ka-add-recaptcha.php';
			} else {
				include_once KA_PLUGIN_DIR . '/includes/front/class-frontend-ka-add-recaptcha.php';
			}
		}

		/**
		 * HOPS compatibility.
		 */
		public function ka_grc_hops_compatibility() {
			if ( class_exists( \Automattic\WooCommerce\Utilities\FeaturesUtil::class ) ) {
				\Automattic\WooCommerce\Utilities\FeaturesUtil::declare_compatibility( 'custom_order_tables', __FILE__, true );
			}
		}

		/**
		 * Function to define global constants.
		 */
		public function ka_grc_global_constents_vars() {
			if ( ! defined( 'KA_GRC_URL' ) ) {
				define( 'KA_GRC_URL', plugin_dir_url( __FILE__ ) );
			}
			if ( ! defined( 'KA_BASENAME' ) ) {
				define( 'KA_BASENAME', plugin_basename( __FILE__ ) );
			}
			if ( ! defined( 'KA_PLUGIN_DIR' ) ) {
				define( 'KA_PLUGIN_DIR', plugin_dir_path( __FILE__ ) );
			}
		}

		/**
		 * Function to load textdomain.
		 */
		public function ka_grc_textdomain() {
			if ( function_exists( 'load_plugin_textdomain' ) ) {
				load_plugin_textdomain( 'recaptcha_verification', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
			}
		}

		/**
		 * Add custom action links on plugin screen.
		 *
		 * @param mixed $actions Plugin Actions Links.
		 * @return array
		 */
		public function ka_grc_plugin_action_links( $actions ) {
			$custom_actions = array(
				'settings' => sprintf( '<a href="%s">%s</a>', admin_url( 'admin.php?page=ka_captcha' ), __( 'Settings', 'recaptcha_verification' ) ),
			);
			return array_merge( $custom_actions, $actions );
		}
	}
	new Main_Ka_Add_Recaptcha();
}
