<?php
/**
 * Captcha Admin settings.
 *
 * @package Google_reCaptcha_for_WooCommerce
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // restict for direct access.
}

if ( ! class_exists( 'Admin_Ka_Add_Recaptcha' ) ) {
	/**
	 * Class Admin_Ka_Add_Recaptcha.
	 */
	class Admin_Ka_Add_Recaptcha extends Main_Ka_Add_Recaptcha {
		/**
		 * Function construct.
		 */
		public function __construct() {
			add_action( 'admin_menu', array( $this, 'add_recaptcha_menu' ) );
			add_action( 'admin_init', array( $this, 'ka_add_register_fields' ) );
			add_action( 'all_admin_notices', array( $this, 'ka_recaptcha_render_tabs' ), 5 );
			add_action( 'admin_enqueue_scripts', array( $this, 'gr_enque_js_call_back' ) );
		}

		/**
		 * Enqueue JS & CSS files.
		 */
		public function gr_enque_js_call_back() {
			// Update: version (1.3.0).
			// Added screen check to only apply scripts to ka_captcha page.
			// Added prefixes to admin JS & CSS files. Enqueued using PHP Constants.
			global $current_screen;
			if ( 'toplevel_page_ka_captcha' === $current_screen->base ) {
				wp_enqueue_script( 'ka-grc-select2-js', KA_GRC_URL . '/assets/js/select2.js', true, '1.0', false );
				wp_enqueue_style( 'ka-grc-select2-css', KA_GRC_URL . '/assets/css/select2.css', false, '1.0' );

				wp_enqueue_script( 'gr_search_user_role', KA_GRC_URL . '/assets/js/ka-grc-admin.js', true, '1.0', false );
				wp_enqueue_style( 'ka-grc-admin', KA_GRC_URL . '/assets/css/ka-grc-admin.css', array(), '1.0' );
			}
		}

		/**
		 * Add reCaptcha menu.
		 */
		public function add_recaptcha_menu() {
			add_menu_page(
				'reCaptcha', // Page title.
				esc_html__( 'reCaptcha', 'recaptcha_verification' ), // Title.
				'manage_options', // Capability.
				'ka_captcha', // slug.
				array( $this, 'create_recaptcha_setting_page' ),
				KA_GRC_URL . '/assets/img/ka-grc-logo.png',
				55
			); // Callback.
		}

		/**
		 * Get current screen.
		 */
		public function get_current_tab() {
			switch ( get_current_screen()->id ) {
				case 'toplevel_page_ka_captcha':
					return 'general';
			}
		}

		/**
		 * Get tab screen ids.
		 */
		public function get_tab_screen_ids() {
			$tabs_screens = array(
				'toplevel_page_ka_captcha',
			);
			return $tabs_screens;
		}

		/**
		 * Function to render tabs.
		 */
		public function ka_recaptcha_render_tabs() {
			$screen = get_current_screen();
			// handle tabs on the relevant WooCommerce pages.
			if ( $screen && in_array( $screen->id, $this->get_tab_screen_ids(), true ) ) {
				$tabs = array(
					'captcha_general_setting' => array(
						'title' => __( 'General Setting', 'recaptcha_verification' ),
						'url'   => admin_url( 'admin.php?page=ka_captcha' ),
					),
					'wcrecaptcha'             => array(
						'title' => __( 'WC Setting', 'recaptcha_verification' ),
						'url'   => admin_url( 'admin.php?page=ka_captcha&tab=wcrecaptcha&subtab_recaptcha=registration_tab' ),
					),
					'wprecaptcha'             => array(
						'title' => __( 'WP Setting', 'recaptcha_verification' ),
						'url'   => admin_url( 'admin.php?page=ka_captcha&tab=wprecaptcha&subtab_wprecaptcha=wpregistration_tab' ),
					),
					// Update: version (1.3.0) Added a new tab for Shortcode.
					'screcaptcha'             => array(
						'title' => __( 'Shortcode', 'recaptcha_verification' ),
						'url'   => admin_url( 'admin.php?page=ka_captcha&tab=screcaptcha' ),
					),
				);
				/**
				 * WooCommerce.
				 *
				 * @since 1.0.0
				 */
				if ( ! is_multisite() && ! in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ), true ) ) {
					unset( $tabs['wcrecaptcha'] );
				}
				// Update: version (1.3.0) Nonce verification.
				if ( isset( $_GET['tab'] ) && isset( $_GET['__page'] ) && ! wp_verify_nonce( sanitize_text_field( wp_unslash( $_GET['__page'] ) ), 'ka_grc_url_nonce' ) ) {
					wp_die( esc_html__( 'Security Violated.', 'recaptcha_verification' ) );
				}
				$active_tab = isset( $_GET['tab'] ) ? sanitize_text_field( wp_unslash( $_GET['tab'] ) ) : 'captcha_general_setting';

				if ( is_array( $tabs ) ) { ?>
					<div class="wrap woocommerce">
						<h2 class="nav-tab-wrapper woo-nav-tab-wrapper">
							<?php
							$current_tab = $this->get_current_tab() === 'general' ? $active_tab :
							$this->get_current_tab();

							foreach ( $tabs as $id => $tab_data ) {
								$class = ( $id === $current_tab ) ? array( 'nav-tab', 'nav-tab-active' ) : array( 'nav-tab' );
								// Update: version (1.3.0) Nonce creation.
								printf( '<a href="%1$s" class="%2$s">%3$s</a>', esc_url( wp_nonce_url( $tab_data['url'], 'ka_grc_url_nonce', '__page' ) ), implode( ' ', array_map( 'sanitize_html_class', $class ) ), esc_html( $tab_data['title'] ) );
							}
							?>
						</h2>
					</div>
					<?php
				}
			}
		}

		/**
		 * Function to create setting page.
		 */
		public function create_recaptcha_setting_page() {
			global $active_tab;
			// Update: version (1.3.0) Nonce verification.
			if ( isset( $_GET['tab'] ) && isset( $_GET['__page'] ) && ! wp_verify_nonce( sanitize_text_field( wp_unslash( $_GET['__page'] ) ), 'ka_grc_url_nonce' ) ) {
				wp_die( esc_html__( 'Security Violated.', 'recaptcha_verification' ) );
			}
			if ( isset( $_GET['tab'] ) ) {
				$active_tab = sanitize_text_field( wp_unslash( $_GET['tab'] ) );
			} else {
				$active_tab = 'captcha_general_setting';
			}
			if ( isset( $_GET['subtab_recaptcha'] ) ) {
				$active_tab_recaptcha = sanitize_text_field( wp_unslash( $_GET['subtab_recaptcha'] ) );
			} else {
				$active_tab_recaptcha = 'registration_tab';
			}
			if ( isset( $_GET['subtab_wprecaptcha'] ) ) {
				$active_tab_wprecaptcha = sanitize_text_field( wp_unslash( $_GET['subtab_wprecaptcha'] ) );
			} else {
				$active_tab_wprecaptcha = 'wpregistration_tab';
			}
			?>

			<div>
				<!-- Title above Tabs -->
				<h2> 
					<?php
					echo esc_html__( 'Recaptcha Setting', 'recaptcha_verification' );
					?>
				</h2>
				<?php settings_errors(); ?>

				<form method="POST" action="options.php" >
					<?php
					if ( 'captcha_general_setting' === $active_tab ) {
						settings_fields( 'wp_captcha_general' );
						do_settings_sections( 'wp_recaptcha_general' );
					}

					if ( 'wcrecaptcha' === $active_tab ) {
						// Update: version(1.3.0) Added textdomain to subtabs.
						$tabs_arr = array(
							'registration_tab'   => __( 'WC Registration', 'recaptcha_verification' ),
							'login_tab'          => __( 'WC Login', 'recaptcha_verification' ),
							'lost_password_tab'  => __( 'WC Lost Password', 'recaptcha_verification' ),
							'checkout_tab'       => __( 'WC Checkout', 'recaptcha_verification' ),
							'payment_tab'        => __( 'WC Payment Method', 'recaptcha_verification' ),
							'payorder_tab'       => __( 'WC Pay for order', 'recaptcha_verification' ),
							'product_review_tab' => __( 'WC Product Review', 'recaptcha_verification' ),
						);
						?>

						<ul class="subsubsub">
							<?php foreach ( $tabs_arr as $key => $lable ) : ?>
								<li>
									<a href="?page=ka_captcha&tab=wcrecaptcha&subtab_recaptcha=<?php echo esc_attr( $key ); ?>" class="<?php echo esc_attr( $active_tab_recaptcha === $key ? 'current' : '' ); ?>"><?php echo esc_html( $lable ); ?></a>
									<?php
									if ( end( $tabs_arr ) !== $lable ) {
										echo esc_html__( ' | ', 'recaptcha_verification' );
									}
									?>
								</li>
							<?php endforeach ?>
						</ul>

						<?php
						$fields_registration = array(
							'registration_tab'   => array( 'captcha-woo-regs', 'recaptcha-woo-regs' ),
							'login_tab'          => array( 'captcha-woo-login', 'recaptcha-woo-login' ),
							'lost_password_tab'  => array( 'captcha-woo-lpass', 'recaptcha-woo-lpass' ),
							'checkout_tab'       => array( 'captcha-woo-guest-checkout', 'recaptcha-woo-guest-checkout' ),
							'payment_tab'        => array( 'captcha-p_method-settings', 'recaptcha-p_method-settings' ),
							'payorder_tab'       => array( 'captcha-p-order-settings', 'recaptcha-p-order-settings' ),
							'product_review_tab' => array( 'captcha-product-review-settings', 'recaptcha-product-review-settings' ),
						);

						foreach ( $fields_registration as $key => $reg_and_sec_arr ) {
							if ( $key === $active_tab_recaptcha ) {
								settings_fields( current( $reg_and_sec_arr ) );
								do_settings_sections( end( $reg_and_sec_arr ) );
							}
						}
					}

					if ( 'wprecaptcha' === $active_tab ) {
						// Update: version(1.3.0) Added textdomain to subtabs.
						$tabs_wparr = array(
							'wpregistration_tab'  => __( 'WP Registration', 'recaptcha_verification' ),
							'wplogin_tab'         => __( 'WP Login', 'recaptcha_verification' ),
							'wplost_password_tab' => __( 'WP Lost Password', 'recaptcha_verification' ),
							'wp_coment_meta_tab'  => __( 'WP Comment', 'recaptcha_verification' ),
						);
						?>

						<ul class="subsubsub">
							<?php foreach ( $tabs_wparr as $key => $wplable ) : ?>
								<li>
									<a href="?page=ka_captcha&tab=wprecaptcha&subtab_wprecaptcha=<?php echo esc_attr( $key ); ?>" class="<?php echo esc_attr( $active_tab_wprecaptcha === $key ? 'current' : '' ); ?>"><?php echo esc_html( $wplable ); ?></a>
									<?php
									if ( end( $tabs_wparr ) !== $wplable ) {
										echo esc_html__( ' | ', 'recaptcha_verification' );
									}
									?>
								</li>
							<?php endforeach ?>
						</ul>

						<?php
						$wpfields_registration = array(
							'wpregistration_tab'  => array( 'wp_captcha_registration', 'wp_recaptcha_registration' ),
							'wplogin_tab'         => array( 'wp_captcha_login', 'wp_recaptcha_login' ),
							'wplost_password_tab' => array( 'wp_captcha_lostpassword', 'wp_recaptcha_lostpassword' ),
							'wp_coment_meta_tab'  => array( 'wp_captcha_coment_meta', 'wp_recaptcha_coment_meta' ),
						);

						foreach ( $wpfields_registration as $key => $wpreg_and_sec_arr ) {
							if ( $key === $active_tab_wprecaptcha ) {
								settings_fields( current( $wpreg_and_sec_arr ) );
								do_settings_sections( end( $wpreg_and_sec_arr ) );
							}
						}
					}
					// Update: version (1.3.0) Added register settings for Shortcode.
					if ( 'screcaptcha' === $active_tab ) {
						settings_fields( 'ka_grc_captcha_shortcode' );
						do_settings_sections( 'ka_grc_recaptcha_shortcode' );
					}
					?>
					<?php submit_button(); ?>
				</form>
			</div>	
			<?php
		}

		/**
		 * Function to register fields.
		 */
		public function ka_add_register_fields() {
			include KA_PLUGIN_DIR . '/includes/settings/general-settings-bckend.php';
			include KA_PLUGIN_DIR . '/includes/settings/woo-registration-page-settings.php';
			include KA_PLUGIN_DIR . '/includes/settings/woo-product-review-settings.php';
			include KA_PLUGIN_DIR . '/includes/settings/woo-login-page-settings.php';
			include KA_PLUGIN_DIR . '/includes/settings/woo-lost-password-setting-captcha.php';
			include KA_PLUGIN_DIR . '/includes/settings/woo-checkout-page.php';
			include KA_PLUGIN_DIR . '/includes/settings/wp-login-captcha-setting.php';
			include KA_PLUGIN_DIR . '/includes/settings/wp-registration-captcha-setting.php';
			include KA_PLUGIN_DIR . '/includes/settings/wp-comment-captcha-setting.php';
			include KA_PLUGIN_DIR . '/includes/settings/wp-lost-password-page-captcha-settings.php';
			include KA_PLUGIN_DIR . '/includes/settings/woo-payment-method-captcha-settings.php';
			include KA_PLUGIN_DIR . '/includes/settings/woo-pay-for-order-captcha.php';
			// Update: version (1.3.0) Include file for shortcode section.
			include KA_PLUGIN_DIR . '/includes/settings/ka-grc-shortcode-captcha.php';
		}
	}
	new Admin_Ka_Add_Recaptcha();
}


