<?php
/**
 * Class responsible for handling Ajax calls.
 *
 * @package Google_reCaptcha_for_WooCommerce
 * @since 1.3.0
 */

if ( ! defined( 'WPINC' ) ) {
	die;
}
if ( ! class_exists( 'Ajax_Controller_Ka_Add_Recaptcha' ) ) {
	/**
	 * Class responsible for handling Ajax calls.
	 */
	class Ajax_Controller_Ka_Add_Recaptcha {
		/**
		 * Hooks into necessary actions to set up ajax functionality.
		 */
		public function __construct() {
			add_action( 'wp_ajax_validation_captchav3', array( $this, 'validation_captchav3' ) );
			add_action( 'wp_ajax_nopriv_validation_captchav3', array( $this, 'validation_captchav3' ) );
		}

		/**
		 * Validates captchav3.
		 */
		public function validation_captchav3() {
			$nonce = isset( $_POST['nonce'] ) ? sanitize_text_field( wp_unslash( $_POST['nonce'] ) ) : '';
			if ( ! wp_verify_nonce( $nonce, 'recaptcha-ajax-nonce' ) ) {
				die( 'Failed ajax security check!' );
			}

			if ( isset( $_POST['captcha_token'] ) ) {
				$captcha_token = isset( $_POST['captcha_token'] ) ? sanitize_text_field( wp_unslash( $_POST['captcha_token'] ) ) : '';
				// Update: version (1.3.0) Getting captcha_api from JS.
				$captcha_api = isset( $_POST['captcha_api'] ) ? sanitize_text_field( wp_unslash( $_POST['captcha_api'] ) ) : '';

				$recaptcha_url      = 'https://www.' . $captcha_api . '/recaptcha/api/siteverify';
				$recaptcha_secret   = get_option( 'add_captcha_secret_key_field' ); // Insert your secret key here.
				$recaptcha_response = $captcha_token;
				$recaptcha          = wp_remote_get( 'https://www.' . $captcha_api . '/recaptcha/api/siteverify?secret=' . $recaptcha_secret . '&response=' . $captcha_token );

				if ( is_array( $recaptcha ) && ! is_wp_error( $recaptcha ) ) {
					$response_body = wp_remote_retrieve_body( $recaptcha ); // Retrieve the response body.

					$recaptcha_data           = json_decode( $response_body ); // Decode the response body.
					$captcha_custom_score_opt = get_option( 'captcha_custom_score_opt' ) ? get_option( 'captcha_custom_score_opt' ) : 0;

					if ( $recaptcha_data->success && $recaptcha_data->score >= $captcha_custom_score_opt ) {
						wp_send_json( array( 'success' => true ) );
						wp_die();
					}
				}
			}
			wp_send_json( array( 'success' => false ) );
			wp_die();
		}
	}
	new Ajax_Controller_Ka_Add_Recaptcha();
}
