<?php
/**
 * Define fille.
 *
 * @package Google_reCaptcha_for_WooCommerce
 */

if ( ! defined( 'ABSPATH' ) ) {
	die;
}

add_settings_section(
	'tab_9_section',         // ID used to identify this section and with which to register options.
	'',                  // Title to be displayed on the administration page.
	'tab_9_section_callback', // Callback used to render the description of the section.
	'recaptcha-p_method-settings'                           // Page on which to add this section of options.
);

add_settings_field(
	'p_method_add_captcha_enable_check', // ID used to identify the field throughout the theme.
	esc_html__( 'reCaptcha on Woo payment method', 'recaptcha_verification' ), // The label to the left of the option interface element.
	'woo_p_method_enable_captcha',   // The name of the function responsible for rendering.
	'recaptcha-p_method-settings', // The page on which this option will be displayed.
	'tab_9_section'// The name of the section to which this field belongs.
);
register_setting(
	'captcha-p_method-settings',
	'p_method_add_captcha_enable_check'
);

add_settings_field(
	'p_method_add_captcha_user_role', // ID used to identify the field throughout the theme.
	esc_html__( 'Select User role', 'recaptcha_verification' ), // The label to the left of the option interface element.
	'woo_p_method_captcha_user_clbk',   // The name of the function responsible for rendering.
	'recaptcha-p_method-settings', // The page on which this option will be displayed.
	'tab_9_section'// The name of the section to which this field belongs.
);
register_setting(
	'captcha-p_method-settings',
	'p_method_add_captcha_user_role'
);

add_settings_field(
	'add_p_method_captcha_field_title', // ID used to identify the field throughout the theme.
	esc_html__( 'Recaptcha Field Title', 'recaptcha_verification' ), // The label to the left of the option interface element.
	'p_method_captcha_field_title_callback',   // The name of the function responsible for rendering.
	'recaptcha-p_method-settings', // The page on which this option will be displayed.
	'tab_9_section'// The name of the section to which this field belongs.
);
register_setting(
	'captcha-p_method-settings',
	'add_p_method_captcha_field_title'
);

add_settings_field(
	'p_method_captcha_themes', // ID used to identify the field throughout the theme.
	esc_html__( 'Recaptcha Themes', 'recaptcha_verification' ), // The label to the left of the option interface element.
	'p_method_captcha_reg_authentication_callback',   // The name of the function responsible for rendering.
	'recaptcha-p_method-settings', // The page on which this option will be displayed.
	'tab_9_section'// The name of the section to which this field belongs.
);
register_setting(
	'captcha-p_method-settings',
	'p_method_captcha_themes'
);

add_settings_field(
	'p_method_add_captcha_size_radio', // ID used to identify the field throughout the theme.
	esc_html__( 'Recaptcha Size', 'recaptcha_verification' ), // The label to the left of the option interface element.
	'p_method_captcha_reg_size_radio_callback',   // The name of the function responsible for rendering.
	'recaptcha-p_method-settings', // The page on which this option will be displayed.
	'tab_9_section'// The name of the section to which this field belongs.
);
register_setting(
	'captcha-p_method-settings',
	'p_method_add_captcha_size_radio'
);

if ( ! function_exists( 'woo_p_method_enable_captcha' ) ) {
	/**
	 * Callback.
	 */
	function woo_p_method_enable_captcha() {
		?>
		<input type="checkbox" name="p_method_add_captcha_enable_check" value="1"<?php checked( get_option( 'p_method_add_captcha_enable_check' ), '1' ); ?>><p><?php echo esc_html__( 'Enables captcha for payment method', 'recaptcha_verification' ); ?></p>
		<br>
		<?php
	}
}

if ( ! function_exists( 'woo_p_method_captcha_user_clbk' ) ) {
	/**
	 * Callback.
	 */
	function woo_p_method_captcha_user_clbk() {
		global $wp_roles;
		$addf_wpm_roles                 = $wp_roles->get_names();
		$p_method_add_captcha_user_role = get_option( 'p_method_add_captcha_user_role' );
		?>
		<span class="ka-grc-tooltip" data-tooltip="<?php echo esc_html__( 'Select user role which you want to show recaptcha.', 'recaptcha_verification' ); ?>"><span class="ka-grc-tooltip-trigger">?</span></span>

		<select class="wc-enhanced-select p_method_add_captcha_user_role" name="p_method_add_captcha_user_role[]" multiple style="width: 40%";>
			<?php
			foreach ( $addf_wpm_roles as $key => $addf_wpm_role ) {
				?>
				<option value="<?php echo esc_attr( $key ); ?>"
				<?php
				if ( in_array( $key, (array) $p_method_add_captcha_user_role, true ) ) {
						echo 'selected="selected"'; }
				?>
				>
				<?php echo esc_html( $addf_wpm_role ); ?></option>
			<?php } ?>
			<option value="guest"  
			<?php
			if ( in_array( 'guest', (array) $p_method_add_captcha_user_role, true ) ) {
				echo 'selected="selected"'; }
			?>
			> <?php echo esc_html__( 'Guest', 'recaptcha_verification' ); ?></option>
		</select>
		<p><?php echo esc_html__( 'If empty, captcha will work for all user roles.', 'recaptcha_verification' ); ?></p>
		<?php
	}
}

if ( ! function_exists( 'p_method_captcha_field_title_callback' ) ) {
	/**
	 * Callback.
	 */
	function p_method_captcha_field_title_callback() {
		?>
		<span class="ka-grc-tooltip" data-tooltip="<?php echo esc_html__( 'Field text for payment method captcha.', 'recaptcha_verification' ); ?>"><span class="ka-grc-tooltip-trigger">?</span></span>
		<input type="text" name="add_p_method_captcha_field_title" value="<?php echo esc_attr( get_option( 'add_p_method_captcha_field_title' ) ); ?>">
		<?php
	}
}
if ( ! function_exists( 'p_method_captcha_reg_authentication_callback' ) ) {
	/**
	 * Callback.
	 */
	function p_method_captcha_reg_authentication_callback() {
		?>
		<input type="radio" name="p_method_captcha_themes"value="light"<?php checked( get_option( 'p_method_captcha_themes' ), 'light' ); ?> checked >
		<label for="Light"><?php echo esc_html__( 'Light', 'recaptcha_verification' ); ?></label>
		<br>
		<input type="radio" name="p_method_captcha_themes" value="dark"<?php checked( get_option( 'p_method_captcha_themes' ), 'dark' ); ?>>
		<label for="Dark"><?php echo esc_html__( 'Dark', 'recaptcha_verification' ); ?></label>
		<br>
		<?php
	}
}
if ( ! function_exists( 'p_method_captcha_reg_size_radio_callback' ) ) {
	/**
	 * Callback.
	 */
	function p_method_captcha_reg_size_radio_callback() {
		?>
		<input type="radio" name="p_method_add_captcha_size_radio" value="normal"<?php checked( get_option( 'p_method_add_captcha_size_radio' ), 'normal' ); ?> checked>
		<label for="Light"><?php echo esc_html__( 'Normal', 'recaptcha_verification' ); ?></label>
		<br>
		<input type="radio" name="p_method_add_captcha_size_radio" value="compact"<?php checked( get_option( 'p_method_add_captcha_size_radio' ), 'compact' ); ?>>
		<label for="Dark"><?php echo esc_html__( 'Compact', 'recaptcha_verification' ); ?></label>
		<br>
		<?php
	}
}
if ( ! function_exists( 'tab_9_section_callback' ) ) {
	/**
	 * Section.
	 */
	function tab_9_section_callback() {
	}
}
